"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub, ctx, group_name: str, opt_in_status: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the opt-in status of the Local Zone and Wavelength Zone group for your account. Use  DescribeAvailabilityZones to view the value for GroupName.

    Args:
        group_name(str): The name of the Availability Zone group, Local Zone group, or Wavelength Zone group.
        opt_in_status(str): Indicates whether you are opted in to the Local Zone group or Wavelength Zone group. The only valid value is opted-in. You must contact AWS Support to opt out of a Local Zone group, or Wavelength Zone group.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.availability_zone.group.modify(
                ctx, group_name=value, opt_in_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.availability_zone.group.modify group_name=value, opt_in_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_availability_zone_group",
        op_kwargs={
            "GroupName": group_name,
            "OptInStatus": opt_in_status,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, tracker_name: str, updates: List) -> Dict:
    r"""
    **Autogenerated function**

    Uploads position update data for one or more devices to a tracker resource. Amazon Location uses the data when reporting the last known device position and position history.  Only one position update is stored per sample time. Location data is sampled at a fixed rate of one position per 30-second interval and retained for 30 days before it's deleted.

    Args:
        tracker_name(str): The name of the tracker resource to update.
        updates(List): Contains the position update details for each device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.update_device_position.batch(
                ctx, tracker_name=value, updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.update_device_position.batch tracker_name=value, updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="batch_update_device_position",
        op_kwargs={"TrackerName": tracker_name, "Updates": updates},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, name: str, assessment_id: str, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Creates an assessment report for the specified assessment.

    Args:
        name(str):  The name of the new assessment report. .
        description(str, optional):  The description of the assessment report. . Defaults to None.
        assessment_id(str):  The identifier for the specified assessment. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.report.init.create(
                ctx, name=value, assessment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.report.init.create name=value, assessment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="create_assessment_report",
        op_kwargs={
            "name": name,
            "description": description,
            "assessmentId": assessment_id,
        },
    )


async def delete(hub, ctx, assessment_id: str, assessment_report_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes an assessment report from an assessment in Audit Manager.

    Args:
        assessment_id(str):  The identifier for the specified assessment. .
        assessment_report_id(str):  The unique identifier for the assessment report. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.report.init.delete(
                ctx, assessment_id=value, assessment_report_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.report.init.delete assessment_id=value, assessment_report_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="delete_assessment_report",
        op_kwargs={
            "assessmentId": assessment_id,
            "assessmentReportId": assessment_report_id,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of assessment reports created in Audit Manager.

    Args:
        next_token(str, optional):  The pagination token used to fetch the next set of results. . Defaults to None.
        max_results(int, optional):  Represents the maximum number of results per page, or per API request call. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.report.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.report.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="list_assessment_reports",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def authorize(
    hub,
    ctx,
    client_vpn_endpoint_id: str,
    target_network_cidr: str,
    access_group_id: str = None,
    authorize_all_groups: bool = None,
    description: str = None,
    client_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an ingress authorization rule to a Client VPN endpoint. Ingress authorization rules act as firewall rules that grant access to networks. You must configure ingress authorization rules to enable clients to access resources in AWS or on-premises networks.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint.
        target_network_cidr(str): The IPv4 address range, in CIDR notation, of the network for which access is being authorized.
        access_group_id(str, optional): The ID of the group to grant access to, for example, the Active Directory group or identity provider (IdP) group. Required if AuthorizeAllGroups is false or not specified. Defaults to None.
        authorize_all_groups(bool, optional): Indicates whether to grant access to all clients. Specify true to grant all clients who successfully establish a VPN connection access to the network. Must be set to true if AccessGroupId is not specified. Defaults to None.
        description(str, optional): A brief description of the authorization rule. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.ingress.authorize(
                ctx, client_vpn_endpoint_id=value, target_network_cidr=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.ingress.authorize client_vpn_endpoint_id=value, target_network_cidr=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="authorize_client_vpn_ingress",
        op_kwargs={
            "ClientVpnEndpointId": client_vpn_endpoint_id,
            "TargetNetworkCidr": target_network_cidr,
            "AccessGroupId": access_group_id,
            "AuthorizeAllGroups": authorize_all_groups,
            "Description": description,
            "ClientToken": client_token,
            "DryRun": dry_run,
        },
    )


async def revoke(
    hub,
    ctx,
    client_vpn_endpoint_id: str,
    target_network_cidr: str,
    access_group_id: str = None,
    revoke_all_groups: bool = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Removes an ingress authorization rule from a Client VPN endpoint.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint with which the authorization rule is associated.
        target_network_cidr(str): The IPv4 address range, in CIDR notation, of the network for which access is being removed.
        access_group_id(str, optional): The ID of the Active Directory group for which to revoke access. . Defaults to None.
        revoke_all_groups(bool, optional): Indicates whether access should be revoked for all clients. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.ingress.revoke(
                ctx, client_vpn_endpoint_id=value, target_network_cidr=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.ingress.revoke client_vpn_endpoint_id=value, target_network_cidr=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="revoke_client_vpn_ingress",
        op_kwargs={
            "ClientVpnEndpointId": client_vpn_endpoint_id,
            "TargetNetworkCidr": target_network_cidr,
            "AccessGroupId": access_group_id,
            "RevokeAllGroups": revoke_all_groups,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, cluster_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of JobListEntry objects of the specified length. Each JobListEntry object is for a job in the specified cluster and contains a job's state, a job's ID, and other information.

    Args:
        cluster_id(str): The 39-character ID for the cluster that you want to list, for example CID123e4567-e89b-12d3-a456-426655440000.
        max_results(int, optional): The number of JobListEntry objects to return. Defaults to None.
        next_token(str, optional): HTTP requests are stateless. To identify what object comes "next" in the list of JobListEntry objects, you have the option of specifying NextToken as the starting point for your returned list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.cluster.job.list_all(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.cluster.job.list_all cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="list_cluster_jobs",
        op_kwargs={
            "ClusterId": cluster_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    stack_name: str,
    template_body: str = None,
    template_url: str = None,
    parameters: List = None,
    disable_rollback: bool = None,
    rollback_configuration: Dict = None,
    timeout_in_minutes: int = None,
    notification_ar_ns: List = None,
    capabilities: List = None,
    resource_types: List = None,
    role_arn: str = None,
    on_failure: str = None,
    stack_policy_body: str = None,
    stack_policy_url: str = None,
    tags: List = None,
    client_request_token: str = None,
    enable_termination_protection: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a stack as specified in the template. After the call completes successfully, the stack creation starts. You can check the status of the stack via the DescribeStacks API.

    Args:
        stack_name(str): The name that is associated with the stack. The name must be unique in the Region in which you are creating the stack.  A stack name can contain only alphanumeric characters (case sensitive) and hyphens. It must start with an alphabetic character and cannot be longer than 128 characters. .
        template_body(str, optional): Structure containing the template body with a minimum length of 1 byte and a maximum length of 51,200 bytes. For more information, go to Template Anatomy in the CloudFormation User Guide. Conditional: You must specify either the TemplateBody or the TemplateURL parameter, but not both. Defaults to None.
        template_url(str, optional): Location of file containing the template body. The URL must point to a template (max size: 460,800 bytes) that is located in an Amazon S3 bucket or a Systems Manager document. For more information, go to the Template Anatomy in the CloudFormation User Guide. Conditional: You must specify either the TemplateBody or the TemplateURL parameter, but not both. Defaults to None.
        parameters(List, optional): A list of Parameter structures that specify input parameters for the stack. For more information, see the Parameter data type. Defaults to None.
        disable_rollback(bool, optional): Set to true to disable rollback of the stack if stack creation failed. You can specify either DisableRollback or OnFailure, but not both. Default: false . Defaults to None.
        rollback_configuration(Dict, optional): The rollback triggers for CloudFormation to monitor during stack creation and updating operations, and for the specified monitoring period afterwards. Defaults to None.
        timeout_in_minutes(int, optional): The amount of time that can pass before the stack status becomes CREATE_FAILED; if DisableRollback is not set or is set to false, the stack will be rolled back. Defaults to None.
        notification_ar_ns(List, optional): The Simple Notification Service (SNS) topic ARNs to publish stack related events. You can find your SNS topic ARNs using the SNS console or your Command Line Interface (CLI). Defaults to None.
        capabilities(List, optional): In some cases, you must explicitly acknowledge that your stack template contains certain capabilities in order for CloudFormation to create the stack.    CAPABILITY_IAM and CAPABILITY_NAMED_IAM  Some stack templates might include resources that can affect permissions in your account; for example, by creating new Identity and Access Management (IAM) users. For those stacks, you must explicitly acknowledge this by specifying one of these capabilities. The following IAM resources require you to specify either the CAPABILITY_IAM or CAPABILITY_NAMED_IAM capability.   If you have IAM resources, you can specify either capability.    If you have IAM resources with custom names, you must specify CAPABILITY_NAMED_IAM.    If you don't specify either of these capabilities, CloudFormation returns an InsufficientCapabilities error.   If your stack template contains these resources, we recommend that you review all permissions associated with them and edit their permissions if necessary.     AWS::IAM::AccessKey      AWS::IAM::Group      AWS::IAM::InstanceProfile      AWS::IAM::Policy      AWS::IAM::Role      AWS::IAM::User      AWS::IAM::UserToGroupAddition    For more information, see Acknowledging IAM Resources in CloudFormation Templates.    CAPABILITY_AUTO_EXPAND  Some template contain macros. Macros perform custom processing on templates; this can include simple actions like find-and-replace operations, all the way to extensive transformations of entire templates. Because of this, users typically create a change set from the processed template, so that they can review the changes resulting from the macros before actually creating the stack. If your stack template contains one or more macros, and you choose to create a stack directly from the processed template, without first reviewing the resulting changes in a change set, you must acknowledge this capability. This includes the AWS::Include and AWS::Serverless transforms, which are macros hosted by CloudFormation. If you want to create a stack from a stack template that contains macros and nested stacks, you must create the stack directly from the template using this capability.  You should only create stacks directly from a stack template that contains macros if you know what processing the macro performs. Each macro relies on an underlying Lambda service function for processing stack templates. Be aware that the Lambda function owner can update the function operation without CloudFormation being notified.  For more information, see Using CloudFormation Macros to Perform Custom Processing on Templates.  . Defaults to None.
        resource_types(List, optional): The template resource types that you have permissions to work with for this create stack action, such as AWS::EC2::Instance, AWS::EC2::*, or Custom::MyCustomInstance. Use the following syntax to describe template resource types: AWS::* (for all Amazon Web Services resources), Custom::* (for all custom resources), Custom::logical_ID  (for a specific custom resource), AWS::service_name::* (for all resources of a particular Amazon Web Services service), and AWS::service_name::resource_logical_ID  (for a specific Amazon Web Services resource). If the list of resource types doesn't include a resource that you're creating, the stack creation fails. By default, CloudFormation grants permissions to all resource types. Identity and Access Management (IAM) uses this parameter for CloudFormation-specific condition keys in IAM policies. For more information, see Controlling Access with Identity and Access Management. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of an Identity and Access Management (IAM) role that CloudFormation assumes to create the stack. CloudFormation uses the role's credentials to make calls on your behalf. CloudFormation always uses this role for all future operations on the stack. As long as users have permission to operate on the stack, CloudFormation uses this role even if the users don't have permission to pass it. Ensure that the role grants least privilege. If you don't specify a value, CloudFormation uses the role that was previously associated with the stack. If no role is available, CloudFormation uses a temporary session that is generated from your user credentials. Defaults to None.
        on_failure(str, optional): Determines what action will be taken if stack creation fails. This must be one of: DO_NOTHING, ROLLBACK, or DELETE. You can specify either OnFailure or DisableRollback, but not both. Default: ROLLBACK . Defaults to None.
        stack_policy_body(str, optional): Structure containing the stack policy body. For more information, go to  Prevent Updates to Stack Resources in the CloudFormation User Guide. You can specify either the StackPolicyBody or the StackPolicyURL parameter, but not both. Defaults to None.
        stack_policy_url(str, optional): Location of a file containing the stack policy. The URL must point to a policy (maximum size: 16 KB) located in an S3 bucket in the same Region as the stack. You can specify either the StackPolicyBody or the StackPolicyURL parameter, but not both. Defaults to None.
        tags(List, optional): Key-value pairs to associate with this stack. CloudFormation also propagates these tags to the resources created in the stack. A maximum number of 50 tags can be specified. Defaults to None.
        client_request_token(str, optional): A unique identifier for this CreateStack request. Specify this token if you plan to retry requests so that CloudFormation knows that you're not attempting to create a stack with the same name. You might retry CreateStack requests to ensure that CloudFormation successfully received them. All events triggered by a given stack operation are assigned the same client request token, which you can use to track operations. For example, if you execute a CreateStack operation with the token token1, then all the StackEvents generated by that operation will have ClientRequestToken set as token1. In the console, stack operations display the client request token on the Events tab. Stack operations that are initiated from the console use the token format Console-StackOperation-ID, which helps you easily identify the stack operation . For example, if you create a stack using the console, each stack event would be assigned the same token in the following format: Console-CreateStack-7f59c3cf-00d2-40c7-b2ff-e75db0987002. . Defaults to None.
        enable_termination_protection(bool, optional): Whether to enable termination protection on the specified stack. If a user attempts to delete a stack with termination protection enabled, the operation fails and the stack remains unchanged. For more information, see Protecting a Stack From Being Deleted in the CloudFormation User Guide. Termination protection is disabled on stacks by default.   For nested stacks, termination protection is set on the root stack and cannot be changed directly on the nested stack. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.init.create(ctx, stack_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.init.create stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="create_stack",
        op_kwargs={
            "StackName": stack_name,
            "TemplateBody": template_body,
            "TemplateURL": template_url,
            "Parameters": parameters,
            "DisableRollback": disable_rollback,
            "RollbackConfiguration": rollback_configuration,
            "TimeoutInMinutes": timeout_in_minutes,
            "NotificationARNs": notification_ar_ns,
            "Capabilities": capabilities,
            "ResourceTypes": resource_types,
            "RoleARN": role_arn,
            "OnFailure": on_failure,
            "StackPolicyBody": stack_policy_body,
            "StackPolicyURL": stack_policy_url,
            "Tags": tags,
            "ClientRequestToken": client_request_token,
            "EnableTerminationProtection": enable_termination_protection,
        },
    )


async def delete(
    hub,
    ctx,
    stack_name: str,
    retain_resources: List = None,
    role_arn: str = None,
    client_request_token: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Deletes a specified stack. Once the call completes successfully, stack deletion starts. Deleted stacks do not show up in the DescribeStacks API if the deletion has been completed successfully.

    Args:
        stack_name(str): The name or the unique stack ID that is associated with the stack.
        retain_resources(List, optional): For stacks in the DELETE_FAILED state, a list of resource logical IDs that are associated with the resources you want to retain. During deletion, CloudFormation deletes the stack but does not delete the retained resources. Retaining resources is useful when you cannot delete a resource, such as a non-empty S3 bucket, but you want to delete the stack. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of an Identity and Access Management (IAM) role that CloudFormation assumes to delete the stack. CloudFormation uses the role's credentials to make calls on your behalf. If you don't specify a value, CloudFormation uses the role that was previously associated with the stack. If no role is available, CloudFormation uses a temporary session that is generated from your user credentials. Defaults to None.
        client_request_token(str, optional): A unique identifier for this DeleteStack request. Specify this token if you plan to retry requests so that CloudFormation knows that you're not attempting to delete a stack with the same name. You might retry DeleteStack requests to ensure that CloudFormation successfully received them. All events triggered by a given stack operation are assigned the same client request token, which you can use to track operations. For example, if you execute a CreateStack operation with the token token1, then all the StackEvents generated by that operation will have ClientRequestToken set as token1. In the console, stack operations display the client request token on the Events tab. Stack operations that are initiated from the console use the token format Console-StackOperation-ID, which helps you easily identify the stack operation . For example, if you create a stack using the console, each stack event would be assigned the same token in the following format: Console-CreateStack-7f59c3cf-00d2-40c7-b2ff-e75db0987002. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.init.delete(ctx, stack_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.init.delete stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="delete_stack",
        op_kwargs={
            "StackName": stack_name,
            "RetainResources": retain_resources,
            "RoleARN": role_arn,
            "ClientRequestToken": client_request_token,
        },
    )


async def describe_all(
    hub, ctx, stack_name: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the description for the specified stack; if no stack name was specified, then it returns the description for all the stacks created.  If the stack does not exist, an AmazonCloudFormationException is returned.

    Args:
        stack_name(str, optional): The name or the unique stack ID that is associated with the stack, which are not always interchangeable:   Running stacks: You can specify either the stack's name or its unique stack ID.   Deleted stacks: You must specify the unique stack ID.   Default: There is no default value. Defaults to None.
        next_token(str, optional): A string that identifies the next page of stacks that you want to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="describe_stacks",
        op_kwargs={"StackName": stack_name, "NextToken": next_token},
    )


async def list_all(
    hub, ctx, next_token: str = None, stack_status_filter: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the summary information for stacks whose status matches the specified StackStatusFilter. Summary information for stacks that have been deleted is kept for 90 days after the stack is deleted. If no StackStatusFilter is specified, summary information for all stacks is returned (including existing stacks and stacks that have been deleted).

    Args:
        next_token(str, optional): A string that identifies the next page of stacks that you want to retrieve. Defaults to None.
        stack_status_filter(List, optional): Stack status to use as a filter. Specify one or more stack status codes to list only stacks with the specified status codes. For a complete list of stack status codes, see the StackStatus parameter of the Stack data type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="list_stacks",
        op_kwargs={"NextToken": next_token, "StackStatusFilter": stack_status_filter},
    )


async def update(
    hub,
    ctx,
    stack_name: str,
    template_body: str = None,
    template_url: str = None,
    use_previous_template: bool = None,
    stack_policy_during_update_body: str = None,
    stack_policy_during_update_url: str = None,
    parameters: List = None,
    capabilities: List = None,
    resource_types: List = None,
    role_arn: str = None,
    rollback_configuration: Dict = None,
    stack_policy_body: str = None,
    stack_policy_url: str = None,
    notification_ar_ns: List = None,
    tags: List = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a stack as specified in the template. After the call completes successfully, the stack update starts. You can check the status of the stack via the DescribeStacks action. To get a copy of the template for an existing stack, you can use the GetTemplate action. For more information about creating an update template, updating a stack, and monitoring the progress of the update, see Updating a Stack.

    Args:
        stack_name(str): The name or unique stack ID of the stack to update.
        template_body(str, optional): Structure containing the template body with a minimum length of 1 byte and a maximum length of 51,200 bytes. (For more information, go to Template Anatomy in the CloudFormation User Guide.) Conditional: You must specify only one of the following parameters: TemplateBody, TemplateURL, or set the UsePreviousTemplate to true. Defaults to None.
        template_url(str, optional): Location of file containing the template body. The URL must point to a template that is located in an Amazon S3 bucket or a Systems Manager document. For more information, go to Template Anatomy in the CloudFormation User Guide. Conditional: You must specify only one of the following parameters: TemplateBody, TemplateURL, or set the UsePreviousTemplate to true. Defaults to None.
        use_previous_template(bool, optional): Reuse the existing template that is associated with the stack that you are updating. Conditional: You must specify only one of the following parameters: TemplateBody, TemplateURL, or set the UsePreviousTemplate to true. Defaults to None.
        stack_policy_during_update_body(str, optional): Structure containing the temporary overriding stack policy body. You can specify either the StackPolicyDuringUpdateBody or the StackPolicyDuringUpdateURL parameter, but not both. If you want to update protected resources, specify a temporary overriding stack policy during this update. If you do not specify a stack policy, the current policy that is associated with the stack will be used. Defaults to None.
        stack_policy_during_update_url(str, optional): Location of a file containing the temporary overriding stack policy. The URL must point to a policy (max size: 16KB) located in an S3 bucket in the same Region as the stack. You can specify either the StackPolicyDuringUpdateBody or the StackPolicyDuringUpdateURL parameter, but not both. If you want to update protected resources, specify a temporary overriding stack policy during this update. If you do not specify a stack policy, the current policy that is associated with the stack will be used. Defaults to None.
        parameters(List, optional): A list of Parameter structures that specify input parameters for the stack. For more information, see the Parameter data type. Defaults to None.
        capabilities(List, optional): In some cases, you must explicitly acknowledge that your stack template contains certain capabilities in order for CloudFormation to update the stack.    CAPABILITY_IAM and CAPABILITY_NAMED_IAM  Some stack templates might include resources that can affect permissions in your account; for example, by creating new Identity and Access Management (IAM) users. For those stacks, you must explicitly acknowledge this by specifying one of these capabilities. The following IAM resources require you to specify either the CAPABILITY_IAM or CAPABILITY_NAMED_IAM capability.   If you have IAM resources, you can specify either capability.    If you have IAM resources with custom names, you must specify CAPABILITY_NAMED_IAM.    If you don't specify either of these capabilities, CloudFormation returns an InsufficientCapabilities error.   If your stack template contains these resources, we recommend that you review all permissions associated with them and edit their permissions if necessary.     AWS::IAM::AccessKey      AWS::IAM::Group      AWS::IAM::InstanceProfile      AWS::IAM::Policy      AWS::IAM::Role      AWS::IAM::User      AWS::IAM::UserToGroupAddition    For more information, see Acknowledging IAM Resources in CloudFormation Templates.    CAPABILITY_AUTO_EXPAND  Some template contain macros. Macros perform custom processing on templates; this can include simple actions like find-and-replace operations, all the way to extensive transformations of entire templates. Because of this, users typically create a change set from the processed template, so that they can review the changes resulting from the macros before actually updating the stack. If your stack template contains one or more macros, and you choose to update a stack directly from the processed template, without first reviewing the resulting changes in a change set, you must acknowledge this capability. This includes the AWS::Include and AWS::Serverless transforms, which are macros hosted by CloudFormation. If you want to update a stack from a stack template that contains macros and nested stacks, you must update the stack directly from the template using this capability.  You should only update stacks directly from a stack template that contains macros if you know what processing the macro performs. Each macro relies on an underlying Lambda service function for processing stack templates. Be aware that the Lambda function owner can update the function operation without CloudFormation being notified.  For more information, see Using CloudFormation Macros to Perform Custom Processing on Templates.  . Defaults to None.
        resource_types(List, optional): The template resource types that you have permissions to work with for this update stack action, such as AWS::EC2::Instance, AWS::EC2::*, or Custom::MyCustomInstance. If the list of resource types doesn't include a resource that you're updating, the stack update fails. By default, CloudFormation grants permissions to all resource types. Identity and Access Management (IAM) uses this parameter for CloudFormation-specific condition keys in IAM policies. For more information, see Controlling Access with Identity and Access Management. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of an Identity and Access Management (IAM) role that CloudFormation assumes to update the stack. CloudFormation uses the role's credentials to make calls on your behalf. CloudFormation always uses this role for all future operations on the stack. As long as users have permission to operate on the stack, CloudFormation uses this role even if the users don't have permission to pass it. Ensure that the role grants least privilege. If you don't specify a value, CloudFormation uses the role that was previously associated with the stack. If no role is available, CloudFormation uses a temporary session that is generated from your user credentials. Defaults to None.
        rollback_configuration(Dict, optional): The rollback triggers for CloudFormation to monitor during stack creation and updating operations, and for the specified monitoring period afterwards. Defaults to None.
        stack_policy_body(str, optional): Structure containing a new stack policy body. You can specify either the StackPolicyBody or the StackPolicyURL parameter, but not both. You might update the stack policy, for example, in order to protect a new resource that you created during a stack update. If you do not specify a stack policy, the current policy that is associated with the stack is unchanged. Defaults to None.
        stack_policy_url(str, optional): Location of a file containing the updated stack policy. The URL must point to a policy (max size: 16KB) located in an S3 bucket in the same Region as the stack. You can specify either the StackPolicyBody or the StackPolicyURL parameter, but not both. You might update the stack policy, for example, in order to protect a new resource that you created during a stack update. If you do not specify a stack policy, the current policy that is associated with the stack is unchanged. Defaults to None.
        notification_ar_ns(List, optional): Amazon Simple Notification Service topic Amazon Resource Names (ARNs) that CloudFormation associates with the stack. Specify an empty list to remove all notification topics. Defaults to None.
        tags(List, optional): Key-value pairs to associate with this stack. CloudFormation also propagates these tags to supported resources in the stack. You can specify a maximum number of 50 tags. If you don't specify this parameter, CloudFormation doesn't modify the stack's tags. If you specify an empty value, CloudFormation removes all associated tags. Defaults to None.
        client_request_token(str, optional): A unique identifier for this UpdateStack request. Specify this token if you plan to retry requests so that CloudFormation knows that you're not attempting to update a stack with the same name. You might retry UpdateStack requests to ensure that CloudFormation successfully received them. All events triggered by a given stack operation are assigned the same client request token, which you can use to track operations. For example, if you execute a CreateStack operation with the token token1, then all the StackEvents generated by that operation will have ClientRequestToken set as token1. In the console, stack operations display the client request token on the Events tab. Stack operations that are initiated from the console use the token format Console-StackOperation-ID, which helps you easily identify the stack operation . For example, if you create a stack using the console, each stack event would be assigned the same token in the following format: Console-CreateStack-7f59c3cf-00d2-40c7-b2ff-e75db0987002. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.init.update(ctx, stack_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.init.update stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="update_stack",
        op_kwargs={
            "StackName": stack_name,
            "TemplateBody": template_body,
            "TemplateURL": template_url,
            "UsePreviousTemplate": use_previous_template,
            "StackPolicyDuringUpdateBody": stack_policy_during_update_body,
            "StackPolicyDuringUpdateURL": stack_policy_during_update_url,
            "Parameters": parameters,
            "Capabilities": capabilities,
            "ResourceTypes": resource_types,
            "RoleARN": role_arn,
            "RollbackConfiguration": rollback_configuration,
            "StackPolicyBody": stack_policy_body,
            "StackPolicyURL": stack_policy_url,
            "NotificationARNs": notification_ar_ns,
            "Tags": tags,
            "ClientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, job: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the specified export job.

    Args:
        job(str): The Amazon Resource Name (arn) of the world export job to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.export_job.cancel(ctx, job=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.export_job.cancel job=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="cancel_world_export_job",
        op_kwargs={"job": job},
    )


async def create(
    hub,
    ctx,
    worlds: List,
    output_location: Dict,
    iam_role: str,
    client_request_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a world export job.

    Args:
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        worlds(List): A list of Amazon Resource Names (arns) that correspond to worlds to export.
        output_location(Dict): The output location.
        iam_role(str): The IAM role that the world export process uses to access the Amazon S3 bucket and put the export.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the world export job. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.export_job.create(
                ctx, worlds=value, output_location=value, iam_role=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.export_job.create worlds=value, output_location=value, iam_role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="create_world_export_job",
        op_kwargs={
            "clientRequestToken": client_request_token,
            "worlds": worlds,
            "outputLocation": output_location,
            "iamRole": iam_role,
            "tags": tags,
        },
    )


async def describe(hub, ctx, job: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a world export job.

    Args:
        job(str): The Amazon Resource Name (arn) of the world export job to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.export_job.describe(ctx, job=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.export_job.describe job=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="describe_world_export_job",
        op_kwargs={"job": job},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists world export jobs.

    Args:
        next_token(str, optional): If the previous paginated request did not return all of the remaining results, the response object's nextToken parameter value is set to a token. To retrieve the next set of results, call ListWorldExportJobs again and assign that token to the request object's nextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. . Defaults to None.
        max_results(int, optional): When this parameter is used, ListWorldExportJobs only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListWorldExportJobs request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListWorldExportJobs returns up to 100 results and a nextToken value if applicable. . Defaults to None.
        filters(List, optional): Optional filters to limit results. You can use generationJobId and templateId. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.export_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.export_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="list_world_export_jobs",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    filter_: List = None,
    host_reservation_id_set: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes reservations that are associated with Dedicated Hosts in your account.

    Args:
        filter_(List, optional): The filters.    instance-family - The instance family (for example, m4).    payment-option - The payment option (NoUpfront | PartialUpfront | AllUpfront).    state - The state of the reservation (payment-pending | payment-failed | active | retired).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        host_reservation_id_set(List, optional): The host reservation IDs. Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.host.reservation.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.host.reservation.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_host_reservations",
        op_kwargs={
            "Filter": filter_,
            "HostReservationIdSet": host_reservation_id_set,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def purchase(
    hub,
    ctx,
    host_id_set: List,
    offering_id: str,
    client_token: str = None,
    currency_code: str = None,
    limit_price: str = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Purchase a reservation with configurations that match those of your Dedicated Host. You must have active Dedicated Hosts in your account before you purchase a reservation. This action results in the specified reservation being purchased and charged to your account.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency. Defaults to None.
        currency_code(str, optional): The currency in which the totalUpfrontPrice, LimitPrice, and totalHourlyPrice amounts are specified. At this time, the only supported currency is USD. Defaults to None.
        host_id_set(List): The IDs of the Dedicated Hosts with which the reservation will be associated.
        limit_price(str, optional): The specified limit is checked against the total upfront cost of the reservation (calculated as the offering's upfront cost multiplied by the host count). If the total upfront cost is greater than the specified price limit, the request fails. This is used to ensure that the purchase does not exceed the expected upfront cost of the purchase. At this time, the only supported currency is USD. For example, to indicate a limit price of USD 100, specify 100.00. Defaults to None.
        offering_id(str): The ID of the offering.
        tag_specifications(List, optional): The tags to apply to the Dedicated Host Reservation during purchase. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.host.reservation.init.purchase(
                ctx, host_id_set=value, offering_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.host.reservation.init.purchase host_id_set=value, offering_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="purchase_host_reservation",
        op_kwargs={
            "ClientToken": client_token,
            "CurrencyCode": currency_code,
            "HostIdSet": host_id_set,
            "LimitPrice": limit_price,
            "OfferingId": offering_id,
            "TagSpecifications": tag_specifications,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, index_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the settings of query suggestions for an index. This is used to check the current settings applied to query suggestions.

    Args:
        index_id(str): The identifier of the index you want to describe query suggestions settings for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.query_suggestion.config.describe(ctx, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.query_suggestion.config.describe index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="describe_query_suggestions_config",
        op_kwargs={"IndexId": index_id},
    )


async def update(
    hub,
    ctx,
    index_id: str,
    mode: str = None,
    query_log_look_back_window_in_days: int = None,
    include_queries_without_user_information: bool = None,
    minimum_number_of_querying_users: int = None,
    minimum_query_count: int = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates the settings of query suggestions for an index. Amazon Kendra supports partial updates, so you only need to provide the fields you want to update. If an update is currently processing (i.e. 'happening'), you need to wait for the update to finish before making another update. Updates to query suggestions settings might not take effect right away. The time for your updated settings to take effect depends on the updates made and the number of search queries in your index. You can still enable/disable query suggestions at any time.

    Args:
        index_id(str): The identifier of the index you want to update query suggestions settings for.
        mode(str, optional): Set the mode to ENABLED or LEARN_ONLY. By default, Amazon Kendra enables query suggestions. LEARN_ONLY mode allows you to turn off query suggestions. You can to update this at any time. In LEARN_ONLY mode, Amazon Kendra continues to learn from new queries to keep suggestions up to date for when you are ready to switch to ENABLED mode again. Defaults to None.
        query_log_look_back_window_in_days(int, optional): How recent your queries are in your query log time window. The time window is the number of days from current day to past days. By default, Amazon Kendra sets this to 180. Defaults to None.
        include_queries_without_user_information(bool, optional):  TRUE to include queries without user information (i.e. all queries, irrespective of the user), otherwise FALSE to only include queries with user information. If you pass user information to Amazon Kendra along with the queries, you can set this flag to FALSE and instruct Amazon Kendra to only consider queries with user information. If you set to FALSE, Amazon Kendra only considers queries searched at least MinimumQueryCount times across MinimumNumberOfQueryingUsers unique users for suggestions. If you set to TRUE, Amazon Kendra ignores all user information and learns from all queries. Defaults to None.
        minimum_number_of_querying_users(int, optional): The minimum number of unique users who must search a query in order for the query to be eligible to suggest to your users. Increasing this number might decrease the number of suggestions. However, this ensures a query is searched by many users and is truly popular to suggest to users. How you tune this setting depends on your specific needs. Defaults to None.
        minimum_query_count(int, optional): The the minimum number of times a query must be searched in order to be eligible to suggest to your users. Decreasing this number increases the number of suggestions. However, this affects the quality of suggestions as it sets a low bar for a query to be considered popular to suggest to users. How you tune this setting depends on your specific needs. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.query_suggestion.config.update(ctx, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.query_suggestion.config.update index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="update_query_suggestions_config",
        op_kwargs={
            "IndexId": index_id,
            "Mode": mode,
            "QueryLogLookBackWindowInDays": query_log_look_back_window_in_days,
            "IncludeQueriesWithoutUserInformation": include_queries_without_user_information,
            "MinimumNumberOfQueryingUsers": minimum_number_of_querying_users,
            "MinimumQueryCount": minimum_query_count,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "import"


async def get(hub, ctx, import_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about an import job started with the StartImport operation.

    Args:
        import_id(str): The identifier of the import job information to return.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.import_.get(ctx, import_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.import.get import_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_import",
        op_kwargs={"importId": import_id},
    )


async def start(
    hub, ctx, payload: bytes, resource_type: str, merge_strategy: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a job to import a resource to Amazon Lex.

    Args:
        payload(bytes): A zip archive in binary format. The archive should contain one file, a JSON file containing the resource to import. The resource should match the type specified in the resourceType field.
        resource_type(str): Specifies the type of resource to export. Each resource also exports any resources that it depends on.    A bot exports dependent intents.   An intent exports dependent slot types.  .
        merge_strategy(str): Specifies the action that the StartImport operation should take when there is an existing resource with the same name.   FAIL_ON_CONFLICT - The import operation is stopped on the first conflict between a resource in the import file and an existing resource. The name of the resource causing the conflict is in the failureReason field of the response to the GetImport operation. OVERWRITE_LATEST - The import operation proceeds even if there is a conflict with an existing resource. The $LASTEST version of the existing resource is overwritten with the data from the import file.  .
        tags(List, optional): A list of tags to add to the imported bot. You can only add tags when you import a bot, you can't add tags to an intent or slot type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.import_.start(
                ctx, payload=value, resource_type=value, merge_strategy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.import.start payload=value, resource_type=value, merge_strategy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="start_import",
        op_kwargs={
            "payload": payload,
            "resourceType": resource_type,
            "mergeStrategy": merge_strategy,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    db_instance_identifier: str,
    source_db_instance_identifier: str,
    db_instance_class: str = None,
    availability_zone: str = None,
    port: int = None,
    multi_az: bool = None,
    auto_minor_version_upgrade: bool = None,
    iops: int = None,
    option_group_name: str = None,
    db_parameter_group_name: str = None,
    publicly_accessible: bool = None,
    tags: List = None,
    db_subnet_group_name: str = None,
    vpc_security_group_ids: List = None,
    storage_type: str = None,
    copy_tags_to_snapshot: bool = None,
    monitoring_interval: int = None,
    monitoring_role_arn: str = None,
    kms_key_id: str = None,
    pre_signed_url: str = None,
    enable_iam_database_authentication: bool = None,
    enable_performance_insights: bool = None,
    performance_insights_kms_key_id: str = None,
    performance_insights_retention_period: int = None,
    enable_cloudwatch_logs_exports: List = None,
    processor_features: List = None,
    use_default_processor_features: bool = None,
    deletion_protection: bool = None,
    domain: str = None,
    domain_iam_role_name: str = None,
    replica_mode: str = None,
    max_allocated_storage: int = None,
    source_region: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DB instance that acts as a read replica for an existing source DB instance. You can create a read replica for a DB instance running MySQL, MariaDB, Oracle, PostgreSQL, or SQL Server. For more information, see Working with Read Replicas in the Amazon RDS User Guide.  Amazon Aurora doesn't support this action. Call the CreateDBInstance action to create a DB instance for an Aurora DB cluster. All read replica DB instances are created with backups disabled. All other DB instance attributes (including DB security groups and DB parameter groups) are inherited from the source DB instance, except as specified.  Your source DB instance must have backup retention enabled.

    Args:
        db_instance_identifier(str): The DB instance identifier of the read replica. This identifier is the unique key that identifies a DB instance. This parameter is stored as a lowercase string.
        source_db_instance_identifier(str): The identifier of the DB instance that will act as the source for the read replica. Each DB instance can have up to five read replicas. Constraints:   Must be the identifier of an existing MySQL, MariaDB, Oracle, PostgreSQL, or SQL Server DB instance.   Can specify a DB instance that is a MySQL read replica only if the source is running MySQL 5.6 or later.   For the limitations of Oracle read replicas, see Read Replica Limitations with Oracle in the Amazon RDS User Guide.   For the limitations of SQL Server read replicas, see Read Replica Limitations with Microsoft SQL Server in the Amazon RDS User Guide.   Can specify a PostgreSQL DB instance only if the source is running PostgreSQL 9.3.5 or later (9.4.7 and higher for cross-region replication).   The specified DB instance must have automatic backups enabled, that is, its backup retention period must be greater than 0.   If the source DB instance is in the same Amazon Web Services Region as the read replica, specify a valid DB instance identifier.   If the source DB instance is in a different Amazon Web Services Region from the read replica, specify a valid DB instance ARN. For more information, see Constructing an ARN for Amazon RDS in the Amazon RDS User Guide. This doesn't apply to SQL Server, which doesn't support cross-region replicas.  .
        db_instance_class(str, optional): The compute and memory capacity of the read replica, for example, db.m4.large. Not all DB instance classes are available in all Amazon Web Services Regions, or for all database engines. For the full list of DB instance classes, and availability for your engine, see DB Instance Class in the Amazon RDS User Guide.  Default: Inherits from the source DB instance. Defaults to None.
        availability_zone(str, optional): The Availability Zone (AZ) where the read replica will be created. Default: A random, system-chosen Availability Zone in the endpoint's Amazon Web Services Region.  Example: us-east-1d . Defaults to None.
        port(int, optional): The port number that the DB instance uses for connections. Default: Inherits from the source DB instance Valid Values: 1150-65535 . Defaults to None.
        multi_az(bool, optional): A value that indicates whether the read replica is in a Multi-AZ deployment.  You can create a read replica as a Multi-AZ DB instance. RDS creates a standby of your replica in another Availability Zone for failover support for the replica. Creating your read replica as a Multi-AZ DB instance is independent of whether the source database is a Multi-AZ DB instance. . Defaults to None.
        auto_minor_version_upgrade(bool, optional): A value that indicates whether minor engine upgrades are applied automatically to the read replica during the maintenance window. Default: Inherits from the source DB instance. Defaults to None.
        iops(int, optional): The amount of Provisioned IOPS (input/output operations per second) to be initially allocated for the DB instance. Defaults to None.
        option_group_name(str, optional): The option group the DB instance is associated with. If omitted, the option group associated with the source instance is used.  For SQL Server, you must use the option group associated with the source instance. . Defaults to None.
        db_parameter_group_name(str, optional): The name of the DB parameter group to associate with this DB instance. If you do not specify a value for DBParameterGroupName, then Amazon RDS uses the DBParameterGroup of source DB instance for a same region read replica, or the default DBParameterGroup for the specified DB engine for a cross region read replica.  Currently, specifying a parameter group for this operation is only supported for Oracle DB instances.  Constraints:   Must be 1 to 255 letters, numbers, or hyphens.   First character must be a letter   Can't end with a hyphen or contain two consecutive hyphens  . Defaults to None.
        publicly_accessible(bool, optional): A value that indicates whether the DB instance is publicly accessible. When the DB instance is publicly accessible, its DNS endpoint resolves to the private IP address from within the DB instance's VPC, and to the public IP address from outside of the DB instance's VPC. Access to the DB instance is ultimately controlled by the security group it uses, and that public access is not permitted if the security group assigned to the DB instance doesn't permit it. When the DB instance isn't publicly accessible, it is an internal DB instance with a DNS name that resolves to a private IP address. For more information, see CreateDBInstance. Defaults to None.
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.
        db_subnet_group_name(str, optional): Specifies a DB subnet group for the DB instance. The new DB instance is created in the VPC associated with the DB subnet group. If no DB subnet group is specified, then the new DB instance isn't created in a VPC. Constraints:   Can only be specified if the source DB instance identifier specifies a DB instance in another Amazon Web Services Region.   If supplied, must match the name of an existing DBSubnetGroup.   The specified DB subnet group must be in the same Amazon Web Services Region in which the operation is running.   All read replicas in one Amazon Web Services Region that are created from the same source DB instance must either:>   Specify DB subnet groups from the same VPC. All these read replicas are created in the same VPC.   Not specify a DB subnet group. All these read replicas are created outside of any VPC.     Example: mySubnetgroup . Defaults to None.
        vpc_security_group_ids(List, optional):  A list of EC2 VPC security groups to associate with the read replica.   Default: The default EC2 VPC security group for the DB subnet group's VPC. . Defaults to None.
        storage_type(str, optional): Specifies the storage type to be associated with the read replica.  Valid values: standard | gp2 | io1   If you specify io1, you must also include a value for the Iops parameter.   Default: io1 if the Iops parameter is specified, otherwise gp2 . Defaults to None.
        copy_tags_to_snapshot(bool, optional): A value that indicates whether to copy all tags from the read replica to snapshots of the read replica. By default, tags are not copied. Defaults to None.
        monitoring_interval(int, optional): The interval, in seconds, between points when Enhanced Monitoring metrics are collected for the read replica. To disable collecting Enhanced Monitoring metrics, specify 0. The default is 0. If MonitoringRoleArn is specified, then you must also set MonitoringInterval to a value other than 0. Valid Values: 0, 1, 5, 10, 15, 30, 60 . Defaults to None.
        monitoring_role_arn(str, optional): The ARN for the IAM role that permits RDS to send enhanced monitoring metrics to Amazon CloudWatch Logs. For example, arn:aws:iam:123456789012:role/emaccess. For information on creating a monitoring role, go to To create an IAM role for Amazon RDS Enhanced Monitoring in the Amazon RDS User Guide. If MonitoringInterval is set to a value other than 0, then you must supply a MonitoringRoleArn value. Defaults to None.
        kms_key_id(str, optional): The Amazon Web Services KMS key identifier for an encrypted read replica. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the Amazon Web Services KMS CMK. If you create an encrypted read replica in the same Amazon Web Services Region as the source DB instance, then do not specify a value for this parameter. A read replica in the same Region is always encrypted with the same Amazon Web Services KMS CMK as the source DB instance. If you create an encrypted read replica in a different Amazon Web Services Region, then you must specify a Amazon Web Services KMS key identifier for the destination Amazon Web Services Region. Amazon Web Services KMS CMKs are specific to the Amazon Web Services Region that they are created in, and you can't use CMKs from one Amazon Web Services Region in another Amazon Web Services Region. You can't create an encrypted read replica from an unencrypted DB instance. Defaults to None.
        pre_signed_url(str, optional): The URL that contains a Signature Version 4 signed request for the CreateDBInstanceReadReplica API action in the source Amazon Web Services Region that contains the source DB instance.  You must specify this parameter when you create an encrypted read replica from another Amazon Web Services Region by using the Amazon RDS API. Don't specify PreSignedUrl when you are creating an encrypted read replica in the same Amazon Web Services Region. The presigned URL must be a valid request for the CreateDBInstanceReadReplica API action that can be executed in the source Amazon Web Services Region that contains the encrypted source DB instance. The presigned URL request must contain the following parameter values:     DestinationRegion - The Amazon Web Services Region that the encrypted read replica is created in. This Amazon Web Services Region is the same one where the CreateDBInstanceReadReplica action is called that contains this presigned URL. For example, if you create an encrypted DB instance in the us-west-1 Amazon Web Services Region, from a source DB instance in the us-east-2 Amazon Web Services Region, then you call the CreateDBInstanceReadReplica action in the us-east-1 Amazon Web Services Region and provide a presigned URL that contains a call to the CreateDBInstanceReadReplica action in the us-west-2 Amazon Web Services Region. For this example, the DestinationRegion in the presigned URL must be set to the us-east-1 Amazon Web Services Region.     KmsKeyId - The Amazon Web Services KMS key identifier for the key to use to encrypt the read replica in the destination Amazon Web Services Region. This is the same identifier for both the CreateDBInstanceReadReplica action that is called in the destination Amazon Web Services Region, and the action contained in the presigned URL.     SourceDBInstanceIdentifier - The DB instance identifier for the encrypted DB instance to be replicated. This identifier must be in the Amazon Resource Name (ARN) format for the source Amazon Web Services Region. For example, if you are creating an encrypted read replica from a DB instance in the us-west-2 Amazon Web Services Region, then your SourceDBInstanceIdentifier looks like the following example: arn:aws:rds:us-west-2:123456789012:instance:mysql-instance1-20161115.    To learn how to generate a Signature Version 4 signed request, see Authenticating Requests: Using Query Parameters (Amazon Web Services Signature Version 4) and Signature Version 4 Signing Process.   If you are using an Amazon Web Services SDK tool or the CLI, you can specify SourceRegion (or --source-region for the CLI) instead of specifying PreSignedUrl manually. Specifying SourceRegion autogenerates a presigned URL that is a valid request for the operation that can be executed in the source Amazon Web Services Region.  SourceRegion isn't supported for SQL Server, because SQL Server on Amazon RDS doesn't support cross-region read replicas. . Defaults to None.
        enable_iam_database_authentication(bool, optional): A value that indicates whether to enable mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts. By default, mapping is disabled. For more information about IAM database authentication, see  IAM Database Authentication for MySQL and PostgreSQL in the Amazon RDS User Guide. . Defaults to None.
        enable_performance_insights(bool, optional): A value that indicates whether to enable Performance Insights for the read replica.  For more information, see Using Amazon Performance Insights in the Amazon RDS User Guide. . Defaults to None.
        performance_insights_kms_key_id(str, optional): The Amazon Web Services KMS key identifier for encryption of Performance Insights data. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the Amazon Web Services KMS customer master key (CMK). If you do not specify a value for PerformanceInsightsKMSKeyId, then Amazon RDS uses your default CMK. There is a default CMK for your Amazon Web Services account. Your Amazon Web Services account has a different default CMK for each Amazon Web Services Region. Defaults to None.
        performance_insights_retention_period(int, optional): The amount of time, in days, to retain Performance Insights data. Valid values are 7 or 731 (2 years). . Defaults to None.
        enable_cloudwatch_logs_exports(List, optional): The list of logs that the new DB instance is to export to CloudWatch Logs. The values in the list depend on the DB engine being used. For more information, see Publishing Database Logs to Amazon CloudWatch Logs  in the Amazon RDS User Guide. Defaults to None.
        processor_features(List, optional): The number of CPU cores and the number of threads per core for the DB instance class of the DB instance. Defaults to None.
        use_default_processor_features(bool, optional): A value that indicates whether the DB instance class of the DB instance uses its default processor features. Defaults to None.
        deletion_protection(bool, optional): A value that indicates whether the DB instance has deletion protection enabled. The database can't be deleted when deletion protection is enabled. By default, deletion protection is disabled. For more information, see  Deleting a DB Instance. . Defaults to None.
        domain(str, optional): The Active Directory directory ID to create the DB instance in. Currently, only MySQL, Microsoft SQL Server, Oracle, and PostgreSQL DB instances can be created in an Active Directory Domain. For more information, see  Kerberos Authentication in the Amazon RDS User Guide. Defaults to None.
        domain_iam_role_name(str, optional): Specify the name of the IAM role to be used when making API calls to the Directory Service. Defaults to None.
        replica_mode(str, optional): The open mode of the replica database: mounted or read-only.  This parameter is only supported for Oracle DB instances.  Mounted DB replicas are included in Oracle Enterprise Edition. The main use case for mounted replicas is cross-Region disaster recovery. The primary database doesn't use Active Data Guard to transmit information to the mounted replica. Because it doesn't accept user connections, a mounted replica can't serve a read-only workload. You can create a combination of mounted and read-only DB replicas for the same primary DB instance. For more information, see Working with Oracle Read Replicas for Amazon RDS in the Amazon RDS User Guide. Defaults to None.
        max_allocated_storage(int, optional): The upper limit to which Amazon RDS can automatically scale the storage of the DB instance. For more information about this setting, including limitations that apply to it, see  Managing capacity automatically with Amazon RDS storage autoscaling in the Amazon RDS User Guide. Defaults to None.
        source_region(str, optional): The ID of the region that contains the source for the read replica. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.instance.read_replica.create(
                ctx, db_instance_identifier=value, source_db_instance_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.instance.read_replica.create db_instance_identifier=value, source_db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="create_db_instance_read_replica",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "SourceDBInstanceIdentifier": source_db_instance_identifier,
            "DBInstanceClass": db_instance_class,
            "AvailabilityZone": availability_zone,
            "Port": port,
            "MultiAZ": multi_az,
            "AutoMinorVersionUpgrade": auto_minor_version_upgrade,
            "Iops": iops,
            "OptionGroupName": option_group_name,
            "DBParameterGroupName": db_parameter_group_name,
            "PubliclyAccessible": publicly_accessible,
            "Tags": tags,
            "DBSubnetGroupName": db_subnet_group_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "StorageType": storage_type,
            "CopyTagsToSnapshot": copy_tags_to_snapshot,
            "MonitoringInterval": monitoring_interval,
            "MonitoringRoleArn": monitoring_role_arn,
            "KmsKeyId": kms_key_id,
            "PreSignedUrl": pre_signed_url,
            "EnableIAMDatabaseAuthentication": enable_iam_database_authentication,
            "EnablePerformanceInsights": enable_performance_insights,
            "PerformanceInsightsKMSKeyId": performance_insights_kms_key_id,
            "PerformanceInsightsRetentionPeriod": performance_insights_retention_period,
            "EnableCloudwatchLogsExports": enable_cloudwatch_logs_exports,
            "ProcessorFeatures": processor_features,
            "UseDefaultProcessorFeatures": use_default_processor_features,
            "DeletionProtection": deletion_protection,
            "Domain": domain,
            "DomainIAMRoleName": domain_iam_role_name,
            "ReplicaMode": replica_mode,
            "MaxAllocatedStorage": max_allocated_storage,
            "SourceRegion": source_region,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, app_id: str, backend_manager_app_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a config object for a backend.

    Args:
        app_id(str): The app ID.
        backend_manager_app_id(str, optional): The app ID for the backend manager. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.config.create(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.config.create app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="create_backend_config",
        op_kwargs={"AppId": app_id, "BackendManagerAppId": backend_manager_app_id},
    )


async def remove(hub, ctx, app_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the AWS resources required to access the Amplify Admin UI.

    Args:
        app_id(str): The app ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.config.remove(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.config.remove app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="remove_backend_config",
        op_kwargs={"AppId": app_id},
    )


async def update(hub, ctx, app_id: str, login_auth_config: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the AWS resources required to access the Amplify Admin UI.

    Args:
        app_id(str): The app ID.
        login_auth_config(Dict, optional): Describes the Amazon Cognito configuration for Admin UI access. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.config.update(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.config.update app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="update_backend_config",
        op_kwargs={"AppId": app_id, "LoginAuthConfig": login_auth_config},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete_multiple(hub, ctx, instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the known host key or certificate used by the Amazon Lightsail browser-based SSH or RDP clients to authenticate an instance. This operation enables the Lightsail browser-based SSH or RDP clients to connect to the instance after a host key mismatch.  Perform this operation only if you were expecting the host key or certificate mismatch or if you are familiar with the new host key or certificate on the instance. For more information, see Troubleshooting connection issues when using the Amazon Lightsail browser-based SSH or RDP client.

    Args:
        instance_name(str): The name of the instance for which you want to reset the host key or certificate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.known_host_key.delete_multiple(
                ctx, instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.known_host_key.delete_multiple instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_known_host_keys",
        op_kwargs={"instanceName": instance_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(
    hub,
    ctx,
    virtual_interface_id: str,
    bgp_peers: List = None,
    test_duration_in_minutes: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the virtual interface failover test that verifies your configuration meets your resiliency requirements by placing the BGP peering session in the DOWN state. You can then send traffic to verify that there are no outages. You can run the test on public, private, transit, and hosted virtual interfaces. You can use ListVirtualInterfaceTestHistory to view the virtual interface test history. If you need to stop the test before the test interval completes, use StopBgpFailoverTest.

    Args:
        virtual_interface_id(str): The ID of the virtual interface you want to test.
        bgp_peers(List, optional): The BGP peers to place in the DOWN state. Defaults to None.
        test_duration_in_minutes(int, optional): The time in minutes that the virtual interface failover test will last. Maximum value: 180 minutes (3 hours). Default: 180 minutes (3 hours). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.bgp.failover_test.start(
                ctx, virtual_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.bgp.failover_test.start virtual_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="start_bgp_failover_test",
        op_kwargs={
            "virtualInterfaceId": virtual_interface_id,
            "bgpPeers": bgp_peers,
            "testDurationInMinutes": test_duration_in_minutes,
        },
    )


async def stop(hub, ctx, virtual_interface_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops the virtual interface failover test.

    Args:
        virtual_interface_id(str): The ID of the virtual interface you no longer want to test.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.bgp.failover_test.stop(
                ctx, virtual_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.bgp.failover_test.stop virtual_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="stop_bgp_failover_test",
        op_kwargs={"virtualInterfaceId": virtual_interface_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    app_id: str,
    branch_name: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Lists the jobs for a branch of an Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        branch_name(str):  The name for a branch. .
        next_token(str, optional):  A pagination token. Set to null to start listing steps from the start. If a non-null pagination token is returned in a result, pass its value in here to list more steps. . Defaults to None.
        max_results(int, optional):  The maximum number of records to list in a single response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.jobs.list(ctx, app_id=value, branch_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.jobs.list app_id=value, branch_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="list_jobs",
        op_kwargs={
            "appId": app_id,
            "branchName": branch_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(
    hub,
    ctx,
    event_bus_name: str = None,
    action: str = None,
    principal: str = None,
    statement_id: str = None,
    condition: Dict = None,
    policy: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Running PutPermission permits the specified AWS account or AWS organization to put events to the specified event bus. Amazon EventBridge (CloudWatch Events) rules in your account are triggered by these events arriving to an event bus in your account.  For another account to send events to your account, that external account must have an EventBridge rule with your account's event bus as a target. To enable multiple AWS accounts to put events to your event bus, run PutPermission once for each of these accounts. Or, if all the accounts are members of the same AWS organization, you can run PutPermission once specifying Principal as "*" and specifying the AWS organization ID in Condition, to grant permissions to all accounts in that organization. If you grant permissions using an organization, then accounts in that organization must specify a RoleArn with proper permissions when they use PutTarget to add your account's event bus as a target. For more information, see Sending and Receiving Events Between AWS Accounts in the Amazon EventBridge User Guide. The permission policy on the default event bus cannot exceed 10 KB in size.

    Args:
        event_bus_name(str, optional): The name of the event bus associated with the rule. If you omit this, the default event bus is used. Defaults to None.
        action(str, optional): The action that you are enabling the other account to perform. Currently, this must be events:PutEvents. Defaults to None.
        principal(str, optional): The 12-digit AWS account ID that you are permitting to put events to your default event bus. Specify "*" to permit any account to put events to your default event bus. If you specify "*" without specifying Condition, avoid creating rules that may match undesirable events. To create more secure rules, make sure that the event pattern for each rule contains an account field with a specific account ID from which to receive events. Rules with an account field do not match any events sent from other accounts. Defaults to None.
        statement_id(str, optional): An identifier string for the external account that you are granting permissions to. If you later want to revoke the permission for this external account, specify this StatementId when you run RemovePermission. Defaults to None.
        condition(Dict, optional): This parameter enables you to limit the permission to accounts that fulfill a certain condition, such as being a member of a certain AWS organization. For more information about AWS Organizations, see What Is AWS Organizations in the AWS Organizations User Guide. If you specify Condition with an AWS organization ID, and specify "*" as the value for Principal, you grant permission to all the accounts in the named organization. The Condition is a JSON string which must contain Type, Key, and Value fields. Defaults to None.
        policy(str, optional): A JSON string that describes the permission policy statement. You can include a Policy parameter in the request instead of using the StatementId, Action, Principal, or Condition parameters. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.permission.put(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.permission.put
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="put_permission",
        op_kwargs={
            "EventBusName": event_bus_name,
            "Action": action,
            "Principal": principal,
            "StatementId": statement_id,
            "Condition": condition,
            "Policy": policy,
        },
    )


async def remove(
    hub,
    ctx,
    statement_id: str = None,
    remove_all_permissions: bool = None,
    event_bus_name: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Revokes the permission of another AWS account to be able to put events to the specified event bus. Specify the account to revoke by the StatementId value that you associated with the account when you granted it permission with PutPermission. You can find the StatementId by using DescribeEventBus.

    Args:
        statement_id(str, optional): The statement ID corresponding to the account that is no longer allowed to put events to the default event bus. Defaults to None.
        remove_all_permissions(bool, optional): Specifies whether to remove all permissions. Defaults to None.
        event_bus_name(str, optional): The name of the event bus to revoke permissions for. If you omit this, the default event bus is used. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.permission.remove(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.permission.remove
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="remove_permission",
        op_kwargs={
            "StatementId": statement_id,
            "RemoveAllPermissions": remove_all_permissions,
            "EventBusName": event_bus_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(
    hub, ctx, spot_instance_request_ids: List, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Cancels one or more Spot Instance requests.  Canceling a Spot Instance request does not terminate running Spot Instances associated with the request.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        spot_instance_request_ids(List): One or more Spot Instance request IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.spot.instance.request.cancel(
                ctx, spot_instance_request_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.spot.instance.request.cancel spot_instance_request_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="cancel_spot_instance_requests",
        op_kwargs={
            "DryRun": dry_run,
            "SpotInstanceRequestIds": spot_instance_request_ids,
        },
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    dry_run: bool = None,
    spot_instance_request_ids: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified Spot Instance requests. You can use DescribeSpotInstanceRequests to find a running Spot Instance by examining the response. If the status of the Spot Instance is fulfilled, the instance ID appears in the response and contains the identifier of the instance. Alternatively, you can use DescribeInstances with a filter to look for instances where the instance lifecycle is spot. We recommend that you set MaxResults to a value between 5 and 1000 to limit the number of results returned. This paginates the output, which makes the list more manageable and returns the results faster. If the list of results exceeds your MaxResults value, then that number of results is returned along with a NextToken value that can be passed to a subsequent DescribeSpotInstanceRequests request to retrieve the remaining results. Spot Instance requests are deleted four hours after they are canceled and their instances are terminated.

    Args:
        filters(List, optional): One or more filters.    availability-zone-group - The Availability Zone group.    create-time - The time stamp when the Spot Instance request was created.    fault-code - The fault code related to the request.    fault-message - The fault message related to the request.    instance-id - The ID of the instance that fulfilled the request.    launch-group - The Spot Instance launch group.    launch.block-device-mapping.delete-on-termination - Indicates whether the EBS volume is deleted on instance termination.    launch.block-device-mapping.device-name - The device name for the volume in the block device mapping (for example, /dev/sdh or xvdh).    launch.block-device-mapping.snapshot-id - The ID of the snapshot for the EBS volume.    launch.block-device-mapping.volume-size - The size of the EBS volume, in GiB.    launch.block-device-mapping.volume-type - The type of EBS volume: gp2 for General Purpose SSD, io1 or io2 for Provisioned IOPS SSD, st1 for Throughput Optimized HDD, sc1for Cold HDD, or standard for Magnetic.    launch.group-id - The ID of the security group for the instance.    launch.group-name - The name of the security group for the instance.    launch.image-id - The ID of the AMI.    launch.instance-type - The type of instance (for example, m3.medium).    launch.kernel-id - The kernel ID.    launch.key-name - The name of the key pair the instance launched with.    launch.monitoring-enabled - Whether detailed monitoring is enabled for the Spot Instance.    launch.ramdisk-id - The RAM disk ID.    launched-availability-zone - The Availability Zone in which the request is launched.    network-interface.addresses.primary - Indicates whether the IP address is the primary private IP address.    network-interface.delete-on-termination - Indicates whether the network interface is deleted when the instance is terminated.    network-interface.description - A description of the network interface.    network-interface.device-index - The index of the device for the network interface attachment on the instance.    network-interface.group-id - The ID of the security group associated with the network interface.    network-interface.network-interface-id - The ID of the network interface.    network-interface.private-ip-address - The primary private IP address of the network interface.    network-interface.subnet-id - The ID of the subnet for the instance.    product-description - The product description associated with the instance (Linux/UNIX | Windows).    spot-instance-request-id - The Spot Instance request ID.    spot-price - The maximum hourly price for any Spot Instance launched to fulfill the request.    state - The state of the Spot Instance request (open | active | closed | cancelled | failed). Spot request status information can help you track your Amazon EC2 Spot Instance requests. For more information, see Spot request status in the Amazon EC2 User Guide for Linux Instances.    status-code - The short code describing the most recent evaluation of your Spot Instance request.    status-message - The message explaining the status of the Spot Instance request.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    type - The type of Spot Instance request (one-time | persistent).    valid-from - The start date of the request.    valid-until - The end date of the request.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        spot_instance_request_ids(List, optional): One or more Spot Instance request IDs. Defaults to None.
        next_token(str, optional): The token to request the next set of results. This value is null when there are no more results to return. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Specify a value between 5 and 1000. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.spot.instance.request.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.spot.instance.request.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_spot_instance_requests",
        op_kwargs={
            "Filters": filters,
            "DryRun": dry_run,
            "SpotInstanceRequestIds": spot_instance_request_ids,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, application_id: str, endpoint_batch_request: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new batch of endpoints for an application or updates the settings and attributes of a batch of existing endpoints for an application. You can also use this operation to define custom attributes for a batch of endpoints. If an update includes one or more values for a custom attribute, Amazon Pinpoint replaces (overwrites) any existing values with the new values.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        endpoint_batch_request(Dict): Specifies a batch of endpoints to create or update and the settings and attributes to set or change for each endpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.endpoint.batch.update(
                ctx, application_id=value, endpoint_batch_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.endpoint.batch.update application_id=value, endpoint_batch_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="update_endpoints_batch",
        op_kwargs={
            "ApplicationId": application_id,
            "EndpointBatchRequest": endpoint_batch_request,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    predictor_backtest_export_job_name: str,
    predictor_arn: str,
    destination: Dict,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Exports backtest forecasts and accuracy metrics generated by the CreatePredictor operation. Two folders containing CSV files are exported to your specified S3 bucket.  The export file names will match the following conventions:  <ExportJobName>_<ExportTimestamp>_<PartNumber>.csv  The <ExportTimestamp> component is in Java SimpleDate format (yyyy-MM-ddTHH-mm-ssZ). You must specify a DataDestination object that includes an Amazon S3 bucket and an AWS Identity and Access Management (IAM) role that Amazon Forecast can assume to access the Amazon S3 bucket. For more information, see aws-forecast-iam-roles.  The Status of the export job must be ACTIVE before you can access the export in your Amazon S3 bucket. To get the status, use the DescribePredictorBacktestExportJob operation.

    Args:
        predictor_backtest_export_job_name(str): The name for the backtest export job.
        predictor_arn(str): The Amazon Resource Name (ARN) of the predictor that you want to export.
        destination(Dict): The destination for an export job. Provide an S3 path, an AWS Identity and Access Management (IAM) role that allows Amazon Forecast to access the location, and an AWS Key Management Service (KMS) key (optional). .
        tags(List, optional): Optional metadata to help you categorize and organize your backtests. Each tag consists of a key and an optional value, both of which you define. Tag keys and values are case sensitive. The following restrictions apply to tags:   For each resource, each tag key must be unique and each tag key must have one value.   Maximum number of tags per resource: 50.   Maximum key length: 128 Unicode characters in UTF-8.   Maximum value length: 256 Unicode characters in UTF-8.   Accepted characters: all letters and numbers, spaces representable in UTF-8, and + - = . _ : / @. If your tagging schema is used across other services and resources, the character restrictions of those services also apply.    Key prefixes cannot include any upper or lowercase combination of aws: or AWS:. Values can have this prefix. If a tag value has aws as its prefix but the key does not, Forecast considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit. You cannot edit or delete tag keys with this prefix.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.predictor.backtest_export_job.create(
                ctx,
                predictor_backtest_export_job_name=value,
                predictor_arn=value,
                destination=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.predictor.backtest_export_job.create predictor_backtest_export_job_name=value, predictor_arn=value, destination=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="create_predictor_backtest_export_job",
        op_kwargs={
            "PredictorBacktestExportJobName": predictor_backtest_export_job_name,
            "PredictorArn": predictor_arn,
            "Destination": destination,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, predictor_backtest_export_job_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a predictor backtest export job.

    Args:
        predictor_backtest_export_job_arn(str): The Amazon Resource Name (ARN) of the predictor backtest export job to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.predictor.backtest_export_job.delete(
                ctx, predictor_backtest_export_job_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.predictor.backtest_export_job.delete predictor_backtest_export_job_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="delete_predictor_backtest_export_job",
        op_kwargs={"PredictorBacktestExportJobArn": predictor_backtest_export_job_arn},
    )


async def describe(hub, ctx, predictor_backtest_export_job_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a predictor backtest export job created using the CreatePredictorBacktestExportJob operation. In addition to listing the properties provided by the user in the CreatePredictorBacktestExportJob request, this operation lists the following properties:    CreationTime     LastModificationTime     Status     Message (if an error occurred)

    Args:
        predictor_backtest_export_job_arn(str): The Amazon Resource Name (ARN) of the predictor backtest export job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.predictor.backtest_export_job.describe(
                ctx, predictor_backtest_export_job_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.predictor.backtest_export_job.describe predictor_backtest_export_job_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="describe_predictor_backtest_export_job",
        op_kwargs={"PredictorBacktestExportJobArn": predictor_backtest_export_job_arn},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of predictor backtest export jobs created using the CreatePredictorBacktestExportJob operation. This operation returns a summary for each backtest export job. You can filter the list using an array of Filter objects. To retrieve the complete set of properties for a particular backtest export job, use the ARN with the DescribePredictorBacktestExportJob operation.

    Args:
        next_token(str, optional): If the result of the previous request was truncated, the response includes a NextToken. To retrieve the next set of results, use the token in the next request. Tokens expire after 24 hours. Defaults to None.
        max_results(int, optional): The number of items to return in the response. Defaults to None.
        filters(List, optional): An array of filters. For each filter, provide a condition and a match statement. The condition is either IS or IS_NOT, which specifies whether to include or exclude the predictor backtest export jobs that match the statement from the list. The match statement consists of a key and a value.  Filter properties     Condition - The condition to apply. Valid values are IS and IS_NOT. To include the predictor backtest export jobs that match the statement, specify IS. To exclude matching predictor backtest export jobs, specify IS_NOT.    Key - The name of the parameter to filter on. Valid values are PredictorArn and Status.    Value - The value to match.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.predictor.backtest_export_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.predictor.backtest_export_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="list_predictor_backtest_export_jobs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Tags an Amazon FSx resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the Amazon FSx resource that you want to tag.
        tags(List): A list of tags for the resource. If a tag with a given key already exists, the value is replaced by the one specified in this parameter.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    This action removes a tag from an Amazon FSx resource.

    Args:
        resource_arn(str): The ARN of the Amazon FSx resource to untag.
        tag_keys(List): A list of keys of tags on the resource to untag. In case the tag key doesn't exist, the call will still succeed to be idempotent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    campaign_arn: str,
    input_list: List,
    user_id: str,
    context: Dict = None,
    filter_arn: str = None,
    filter_values: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Re-ranks a list of recommended items for the given user. The first item in the list is deemed the most likely item to be of interest to the user.  The solution backing the campaign must have been created using a recipe of type PERSONALIZED_RANKING.

    Args:
        campaign_arn(str): The Amazon Resource Name (ARN) of the campaign to use for generating the personalized ranking.
        input_list(List): A list of items (by itemId) to rank. If an item was not included in the training dataset, the item is appended to the end of the reranked list. The maximum is 500.
        user_id(str): The user for which you want the campaign to provide a personalized ranking.
        context(Dict, optional): The contextual metadata to use when getting recommendations. Contextual metadata includes any interaction information that might be relevant when getting a user's recommendations, such as the user's current location or device type. Defaults to None.
        filter_arn(str, optional): The Amazon Resource Name (ARN) of a filter you created to include items or exclude items from recommendations for a given user. For more information, see Filtering Recommendations. Defaults to None.
        filter_values(Dict, optional): The values to use when filtering recommendations. For each placeholder parameter in your filter expression, provide the parameter name (in matching case) as a key and the filter value(s) as the corresponding value. Separate multiple values for one parameter with a comma.  For filter expressions that use an INCLUDE element to include items, you must provide values for all parameters that are defined in the expression. For filters with expressions that use an EXCLUDE element to exclude items, you can omit the filter-values.In this case, Amazon Personalize doesn't use that portion of the expression to filter recommendations. For more information, see Filtering Recommendations. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize_runtime.personalized_ranking.get(
                ctx, campaign_arn=value, input_list=value, user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize_runtime.personalized_ranking.get campaign_arn=value, input_list=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize-runtime",
        operation="get_personalized_ranking",
        op_kwargs={
            "campaignArn": campaign_arn,
            "inputList": input_list,
            "userId": user_id,
            "context": context,
            "filterArn": filter_arn,
            "filterValues": filter_values,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def remove(
    hub, ctx, resource_type: str, resource_id: str, tag_keys: List
) -> Dict:
    r"""
    **Autogenerated function**

    Removes tag keys from the specified resource.

    Args:
        resource_type(str): The type of resource from which you want to remove a tag.  The ManagedInstance type for this API operation is only for on-premises managed instances. Specify the name of the managed instance in the following format: mi-ID_number . For example, mi-1a2b3c4d5e6f. .
        resource_id(str): The ID of the resource from which you want to remove tags. For example: ManagedInstance: mi-012345abcde MaintenanceWindow: mw-012345abcde PatchBaseline: pb-012345abcde OpsMetadata object: ResourceID for tagging is created from the Amazon Resource Name (ARN) for the object. Specifically, ResourceID is created from the strings that come after the word opsmetadata in the ARN. For example, an OpsMetadata object with an ARN of arn:aws:ssm:us-east-2:1234567890:opsmetadata/aws/ssm/MyGroup/appmanager has a ResourceID of either aws/ssm/MyGroup/appmanager or /aws/ssm/MyGroup/appmanager. For the Document and Parameter values, use the name of the resource.  The ManagedInstance type for this API operation is only for on-premises managed instances. Specify the name of the managed instance in the following format: mi-ID_number. For example, mi-1a2b3c4d5e6f. .
        tag_keys(List): Tag keys that you want to remove from the specified resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.tags.from_resource.remove(
                ctx, resource_type=value, resource_id=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.tags.from_resource.remove resource_type=value, resource_id=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="remove_tags_from_resource",
        op_kwargs={
            "ResourceType": resource_type,
            "ResourceId": resource_id,
            "TagKeys": tag_keys,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    connection_token: str,
    contact_id: str = None,
    max_results: int = None,
    next_token: str = None,
    scan_direction: str = None,
    sort_order: str = None,
    start_position: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a transcript of the session, including details about any attachments. Note that ConnectionToken is used for invoking this API instead of ParticipantToken. The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.

    Args:
        contact_id(str, optional): The contactId from the current contact chain for which transcript is needed. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the page. Default: 10. . Defaults to None.
        next_token(str, optional): The pagination token. Use the value returned previously in the next subsequent request to retrieve the next set of results. Defaults to None.
        scan_direction(str, optional): The direction from StartPosition from which to retrieve message. Default: BACKWARD when no StartPosition is provided, FORWARD with StartPosition. . Defaults to None.
        sort_order(str, optional): The sort order for the records. Default: DESCENDING. Defaults to None.
        start_position(Dict, optional): A filtering option for where to start. Defaults to None.
        connection_token(str): The authentication token associated with the participant's connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connectparticipant.transcript.get(ctx, connection_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connectparticipant.transcript.get connection_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connectparticipant",
        operation="get_transcript",
        op_kwargs={
            "ContactId": contact_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "ScanDirection": scan_direction,
            "SortOrder": sort_order,
            "StartPosition": start_position,
            "ConnectionToken": connection_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    aws_account_id: str,
    data_set_id: str,
    name: str,
    physical_table_map: Dict,
    import_mode: str,
    logical_table_map: Dict = None,
    column_groups: List = None,
    field_folders: Dict = None,
    permissions: List = None,
    row_level_permission_data_set: Dict = None,
    row_level_permission_tag_configuration: Dict = None,
    column_level_permission_rules: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a dataset.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_set_id(str): An ID for the dataset that you want to create. This ID is unique per Region; for each Amazon Web Services account;.
        name(str): The display name for the dataset.
        physical_table_map(Dict): Declares the physical tables that are available in the underlying data sources.
        logical_table_map(Dict, optional): Configures the combination and transformation of the data from the physical tables. Defaults to None.
        import_mode(str): Indicates whether you want to import the data into SPICE.
        column_groups(List, optional): Groupings of columns that work together in certain QuickSight features. Currently, only geospatial hierarchy is supported. Defaults to None.
        field_folders(Dict, optional): The folder that contains fields and nested subfolders for your dataset. Defaults to None.
        permissions(List, optional): A list of resource permissions on the dataset. Defaults to None.
        row_level_permission_data_set(Dict, optional): The row-level security configuration for the data that you want to create. Defaults to None.
        row_level_permission_tag_configuration(Dict, optional): The configuration of tags on a dataset to set row-level security. Row-level security tags are currently supported for anonymous embedding only. Defaults to None.
        column_level_permission_rules(List, optional): A set of one or more definitions of a  ColumnLevelPermissionRule . Defaults to None.
        tags(List, optional): Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.set_.init.create(
                ctx,
                aws_account_id=value,
                data_set_id=value,
                name=value,
                physical_table_map=value,
                import_mode=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.set_.init.create aws_account_id=value, data_set_id=value, name=value, physical_table_map=value, import_mode=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_data_set",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DataSetId": data_set_id,
            "Name": name,
            "PhysicalTableMap": physical_table_map,
            "LogicalTableMap": logical_table_map,
            "ImportMode": import_mode,
            "ColumnGroups": column_groups,
            "FieldFolders": field_folders,
            "Permissions": permissions,
            "RowLevelPermissionDataSet": row_level_permission_data_set,
            "RowLevelPermissionTagConfiguration": row_level_permission_tag_configuration,
            "ColumnLevelPermissionRules": column_level_permission_rules,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, aws_account_id: str, data_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a dataset.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_set_id(str): The ID for the dataset that you want to create. This ID is unique per Region; for each Amazon Web Services account;.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.set_.init.delete(
                ctx, aws_account_id=value, data_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.set_.init.delete aws_account_id=value, data_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_data_set",
        op_kwargs={"AwsAccountId": aws_account_id, "DataSetId": data_set_id},
    )


async def describe(hub, ctx, aws_account_id: str, data_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a dataset.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_set_id(str): The ID for the dataset that you want to create. This ID is unique per Region; for each Amazon Web Services account;.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.set_.init.describe(
                ctx, aws_account_id=value, data_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.set_.init.describe aws_account_id=value, data_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_data_set",
        op_kwargs={"AwsAccountId": aws_account_id, "DataSetId": data_set_id},
    )


async def list_all(
    hub, ctx, aws_account_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the datasets belonging to the current Amazon Web Services account; in an Region;. The permissions resource is arn:aws:quicksight:region:aws-account-id:dataset/*.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.set_.init.list_all(ctx, aws_account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.set_.init.list_all aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_data_sets",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    aws_account_id: str,
    data_set_id: str,
    name: str,
    physical_table_map: Dict,
    import_mode: str,
    logical_table_map: Dict = None,
    column_groups: List = None,
    field_folders: Dict = None,
    row_level_permission_data_set: Dict = None,
    row_level_permission_tag_configuration: Dict = None,
    column_level_permission_rules: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a dataset.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_set_id(str): The ID for the dataset that you want to update. This ID is unique per Region; for each Amazon Web Services account;.
        name(str): The display name for the dataset.
        physical_table_map(Dict): Declares the physical tables that are available in the underlying data sources.
        logical_table_map(Dict, optional): Configures the combination and transformation of the data from the physical tables. Defaults to None.
        import_mode(str): Indicates whether you want to import the data into SPICE.
        column_groups(List, optional): Groupings of columns that work together in certain QuickSight features. Currently, only geospatial hierarchy is supported. Defaults to None.
        field_folders(Dict, optional): The folder that contains fields and nested subfolders for your dataset. Defaults to None.
        row_level_permission_data_set(Dict, optional): The row-level security configuration for the data you want to create. Defaults to None.
        row_level_permission_tag_configuration(Dict, optional): The configuration of tags on a dataset to set row-level security. Row-level security tags are currently supported for anonymous embedding only. Defaults to None.
        column_level_permission_rules(List, optional): A set of one or more definitions of a  ColumnLevelPermissionRule . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.set_.init.update(
                ctx,
                aws_account_id=value,
                data_set_id=value,
                name=value,
                physical_table_map=value,
                import_mode=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.set_.init.update aws_account_id=value, data_set_id=value, name=value, physical_table_map=value, import_mode=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_data_set",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DataSetId": data_set_id,
            "Name": name,
            "PhysicalTableMap": physical_table_map,
            "LogicalTableMap": logical_table_map,
            "ImportMode": import_mode,
            "ColumnGroups": column_groups,
            "FieldFolders": field_folders,
            "RowLevelPermissionDataSet": row_level_permission_data_set,
            "RowLevelPermissionTagConfiguration": row_level_permission_tag_configuration,
            "ColumnLevelPermissionRules": column_level_permission_rules,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    function_definition_id: str,
    amzn_client_token: str = None,
    default_config: Dict = None,
    functions: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a version of a Lambda function definition that has already been defined.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        default_config(Dict, optional): The default configuration that applies to all Lambda functions in this function definition version. Individual Lambda functions can override these settings. Defaults to None.
        function_definition_id(str): The ID of the Lambda function definition.
        functions(List, optional): A list of Lambda functions in this function definition version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.function_definition.version.create(
                ctx, function_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.function_definition.version.create function_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_function_definition_version",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "DefaultConfig": default_config,
            "FunctionDefinitionId": function_definition_id,
            "Functions": functions,
        },
    )


async def get(
    hub,
    ctx,
    function_definition_id: str,
    function_definition_version_id: str,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a Lambda function definition version, including which Lambda functions are included in the version and their configurations.

    Args:
        function_definition_id(str): The ID of the Lambda function definition.
        function_definition_version_id(str): The ID of the function definition version. This value maps to the ''Version'' property of the corresponding ''VersionInformation'' object, which is returned by ''ListFunctionDefinitionVersions'' requests. If the version is the last one that was associated with a function definition, the value also maps to the ''LatestVersion'' property of the corresponding ''DefinitionInformation'' object.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.function_definition.version.get(
                ctx, function_definition_id=value, function_definition_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.function_definition.version.get function_definition_id=value, function_definition_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_function_definition_version",
        op_kwargs={
            "FunctionDefinitionId": function_definition_id,
            "FunctionDefinitionVersionId": function_definition_version_id,
            "NextToken": next_token,
        },
    )


async def list_all(
    hub,
    ctx,
    function_definition_id: str,
    max_results: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of a Lambda function definition.

    Args:
        function_definition_id(str): The ID of the Lambda function definition.
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.function_definition.version.list_all(
                ctx, function_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.function_definition.version.list_all function_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_function_definition_versions",
        op_kwargs={
            "FunctionDefinitionId": function_definition_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_id: str, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all tags on a directory.

    Args:
        resource_id(str): Identifier (ID) of the directory for which you want to retrieve tags.
        next_token(str, optional): Reserved for future use. Defaults to None.
        limit(int, optional): Reserved for future use. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.tags.for_resource.list(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.tags.for_resource.list resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceId": resource_id, "NextToken": next_token, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def authorize(
    hub,
    ctx,
    db_security_group_name: str,
    cidrip: str = None,
    ec2_security_group_name: str = None,
    ec2_security_group_id: str = None,
    ec2_security_group_owner_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Enables ingress to a DBSecurityGroup using one of two forms of authorization. First, EC2 or VPC security groups can be added to the DBSecurityGroup if the application using the database is running on EC2 or VPC instances. Second, IP ranges are available if the application accessing your database is running on the Internet. Required parameters for this API are one of CIDR range, EC2SecurityGroupId for VPC, or (EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId for non-VPC).  You can't authorize ingress from an EC2 security group in one Amazon Web Services Region to an Amazon RDS DB instance in another. You can't authorize ingress from a VPC security group in one VPC to an Amazon RDS DB instance in another.  For an overview of CIDR ranges, go to the Wikipedia Tutorial.

    Args:
        db_security_group_name(str): The name of the DB security group to add authorization to.
        cidrip(str, optional): The IP range to authorize. Defaults to None.
        ec2_security_group_name(str, optional):  Name of the EC2 security group to authorize. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided. . Defaults to None.
        ec2_security_group_id(str, optional):  Id of the EC2 security group to authorize. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided. . Defaults to None.
        ec2_security_group_owner_id(str, optional):  Amazon Web Services account number of the owner of the EC2 security group specified in the EC2SecurityGroupName parameter. The Amazon Web Services access key ID isn't an acceptable value. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.security_group.ingress.authorize(
                ctx, db_security_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.security_group.ingress.authorize db_security_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="authorize_db_security_group_ingress",
        op_kwargs={
            "DBSecurityGroupName": db_security_group_name,
            "CIDRIP": cidrip,
            "EC2SecurityGroupName": ec2_security_group_name,
            "EC2SecurityGroupId": ec2_security_group_id,
            "EC2SecurityGroupOwnerId": ec2_security_group_owner_id,
        },
    )


async def revoke(
    hub,
    ctx,
    db_security_group_name: str,
    cidrip: str = None,
    ec2_security_group_name: str = None,
    ec2_security_group_id: str = None,
    ec2_security_group_owner_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Revokes ingress from a DBSecurityGroup for previously authorized IP ranges or EC2 or VPC security groups. Required parameters for this API are one of CIDRIP, EC2SecurityGroupId for VPC, or (EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId).

    Args:
        db_security_group_name(str): The name of the DB security group to revoke ingress from.
        cidrip(str, optional):  The IP range to revoke access from. Must be a valid CIDR range. If CIDRIP is specified, EC2SecurityGroupName, EC2SecurityGroupId and EC2SecurityGroupOwnerId can't be provided. . Defaults to None.
        ec2_security_group_name(str, optional):  The name of the EC2 security group to revoke access from. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided. . Defaults to None.
        ec2_security_group_id(str, optional):  The id of the EC2 security group to revoke access from. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided. . Defaults to None.
        ec2_security_group_owner_id(str, optional):  The Amazon Web Services account number of the owner of the EC2 security group specified in the EC2SecurityGroupName parameter. The Amazon Web Services access key ID isn't an acceptable value. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.security_group.ingress.revoke(
                ctx, db_security_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.security_group.ingress.revoke db_security_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="revoke_db_security_group_ingress",
        op_kwargs={
            "DBSecurityGroupName": db_security_group_name,
            "CIDRIP": cidrip,
            "EC2SecurityGroupName": ec2_security_group_name,
            "EC2SecurityGroupId": ec2_security_group_id,
            "EC2SecurityGroupOwnerId": ec2_security_group_owner_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def infer(hub, ctx, text: str) -> Dict:
    r"""
    **Autogenerated function**

    InferICD10CM detects medical conditions as entities listed in a patient record and links those entities to normalized concept identifiers in the ICD-10-CM knowledge base from the Centers for Disease Control. Amazon Comprehend Medical only detects medical entities in English language texts.

    Args:
        text(str): The input text used for analysis. The input for InferICD10CM is a string from 1 to 10000 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehendmedical.icd10_cm.init.infer(ctx, text=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehendmedical.icd10_cm.init.infer text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehendmedical",
        operation="infer_icd10_cm",
        op_kwargs={"Text": text},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the existing conference preferences.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.conference.preference.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.conference.preference.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_conference_preference",
        op_kwargs={},
    )


async def put(hub, ctx, conference_preference: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Sets the conference preferences on a specific conference provider at the account level.

    Args:
        conference_preference(Dict): The conference preference of a specific conference provider.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.conference.preference.put(
                ctx, conference_preference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.conference.preference.put conference_preference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="put_conference_preference",
        op_kwargs={"ConferencePreference": conference_preference},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "ip_set"


async def create(
    hub,
    ctx,
    name: str,
    scope: str,
    ip_address_version: str,
    addresses: List,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an IPSet, which you use to identify web requests that originate from specific IP addresses or ranges of IP addresses. For example, if you're receiving a lot of requests from a ranges of IP addresses, you can configure WAF to block them using an IPSet that lists those IP addresses.

    Args:
        name(str): The name of the IP set. You cannot change the name of an IPSet after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        description(str, optional): A description of the IP set that helps with identification. . Defaults to None.
        ip_address_version(str): Specify IPV4 or IPV6. .
        addresses(List): Contains an array of strings that specify one or more IP addresses or blocks of IP addresses in Classless Inter-Domain Routing (CIDR) notation. WAF supports all IPv4 and IPv6 CIDR ranges except for /0.  Examples:    To configure WAF to allow, block, or count requests that originated from the IP address 192.0.2.44, specify 192.0.2.44/32.   To configure WAF to allow, block, or count requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify 192.0.2.0/24.   To configure WAF to allow, block, or count requests that originated from the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify 1111:0000:0000:0000:0000:0000:0000:0111/128.   To configure WAF to allow, block, or count requests that originated from IP addresses 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify 1111:0000:0000:0000:0000:0000:0000:0000/64.   For more information about CIDR notation, see the Wikipedia entry Classless Inter-Domain Routing.
        tags(List, optional): An array of key:value pairs to associate with the resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.ip_set_.create(
                ctx, name=value, scope=value, ip_address_version=value, addresses=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.ip_set.create name=value, scope=value, ip_address_version=value, addresses=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="create_ip_set",
        op_kwargs={
            "Name": name,
            "Scope": scope,
            "Description": description,
            "IPAddressVersion": ip_address_version,
            "Addresses": addresses,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str, scope: str, id_: str, lock_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified IPSet.

    Args:
        name(str): The name of the IP set. You cannot change the name of an IPSet after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
        lock_token(str): A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.ip_set_.delete(
                ctx, name=value, scope=value, id_=value, lock_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.ip_set.delete name=value, scope=value, id_=value, lock_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="delete_ip_set",
        op_kwargs={"Name": name, "Scope": scope, "Id": id_, "LockToken": lock_token},
    )


async def get(hub, ctx, name: str, scope: str, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the specified IPSet.

    Args:
        name(str): The name of the IP set. You cannot change the name of an IPSet after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.ip_set_.get(ctx, name=value, scope=value, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.ip_set.get name=value, scope=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="get_ip_set",
        op_kwargs={"Name": name, "Scope": scope, "Id": id_},
    )


async def list_all(
    hub, ctx, scope: str, next_marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an array of IPSetSummary objects for the IP sets that you manage.

    Args:
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        next_marker(str, optional): When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request. Defaults to None.
        limit(int, optional): The maximum number of objects that you want WAF to return for this request. If more objects are available, in the response, WAF provides a NextMarker value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.ip_set_.list_all(ctx, scope=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.ip_set.list_all scope=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="list_ip_sets",
        op_kwargs={"Scope": scope, "NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub,
    ctx,
    name: str,
    scope: str,
    id_: str,
    addresses: List,
    lock_token: str,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified IPSet.   This operation completely replaces the mutable specifications that you already have for the IP set with the ones that you provide to this call. To modify the IP set, retrieve it by calling GetIPSet, update the settings as needed, and then provide the complete IP set specification to this call.

    Args:
        name(str): The name of the IP set. You cannot change the name of an IPSet after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
        description(str, optional): A description of the IP set that helps with identification. . Defaults to None.
        addresses(List): Contains an array of strings that specify one or more IP addresses or blocks of IP addresses in Classless Inter-Domain Routing (CIDR) notation. WAF supports all IPv4 and IPv6 CIDR ranges except for /0.  Examples:    To configure WAF to allow, block, or count requests that originated from the IP address 192.0.2.44, specify 192.0.2.44/32.   To configure WAF to allow, block, or count requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify 192.0.2.0/24.   To configure WAF to allow, block, or count requests that originated from the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify 1111:0000:0000:0000:0000:0000:0000:0111/128.   To configure WAF to allow, block, or count requests that originated from IP addresses 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify 1111:0000:0000:0000:0000:0000:0000:0000/64.   For more information about CIDR notation, see the Wikipedia entry Classless Inter-Domain Routing.
        lock_token(str): A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.ip_set_.update(
                ctx, name=value, scope=value, id_=value, addresses=value, lock_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.ip_set.update name=value, scope=value, id_=value, addresses=value, lock_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="update_ip_set",
        op_kwargs={
            "Name": name,
            "Scope": scope,
            "Id": id_,
            "Description": description,
            "Addresses": addresses,
            "LockToken": lock_token,
        },
    )
